diff --git a/dumux/porousmediumflow/2p2c/volumevariables.hh b/dumux/porousmediumflow/2p2c/volumevariables.hh
index 789340d4f1ccbd55c2426dd596ec7fced6a2379b..326078413c9215ae2a2f735211f829ea03e8bf4c 100644
--- a/dumux/porousmediumflow/2p2c/volumevariables.hh
+++ b/dumux/porousmediumflow/2p2c/volumevariables.hh
@@ -558,7 +558,7 @@ public:
     Scalar diffusionCoefficient(int phaseIdx, int compIdx) const
     {
         if(phaseIdx == compIdx)
-            DUNE_THROW(Dune::InvalidStateException, "Diffusion coeffiecient called for phaseIdx = compIdx");
+            DUNE_THROW(Dune::InvalidStateException, "Diffusion coefficient called for phaseIdx = compIdx");
         else
             return diffCoeff_[phaseIdx];
     }
diff --git a/dumux/porousmediumflow/2pnc/volumevariables.hh b/dumux/porousmediumflow/2pnc/volumevariables.hh
index ab9e9dd9e3efa87f77938f99f4371d79619f6f89..0e8c05a0454c3c84d898d2c67bb49d91b9d2fe66 100644
--- a/dumux/porousmediumflow/2pnc/volumevariables.hh
+++ b/dumux/porousmediumflow/2pnc/volumevariables.hh
@@ -472,7 +472,7 @@ public:
         else if (compIdx > phaseIdx)
             return diffCoefficient_[phaseIdx][compIdx-1];
         else
-            DUNE_THROW(Dune::InvalidStateException, "Diffusion coeffiecient called for phaseIdx = compIdx");
+            DUNE_THROW(Dune::InvalidStateException, "Diffusion coefficient called for phaseIdx = compIdx");
     }
 
     /*!
@@ -516,7 +516,7 @@ private:
         else if (compIdx > phaseIdx)
             diffCoefficient_[phaseIdx][compIdx-1] = std::move(d);
         else
-            DUNE_THROW(Dune::InvalidStateException, "Diffusion coeffiecient for phaseIdx = compIdx doesn't exist");
+            DUNE_THROW(Dune::InvalidStateException, "Diffusion coefficient for phaseIdx = compIdx doesn't exist");
     }
 
     std::array<std::array<Scalar, numComponents-1>, numPhases> diffCoefficient_;
diff --git a/dumux/porousmediumflow/3pwateroil/volumevariables.hh b/dumux/porousmediumflow/3pwateroil/volumevariables.hh
index 823adbbc501c1ef55911299d94dd528cf52c38bb..7b7cf5f635a292dca2abaa677b977061deee6bfa 100644
--- a/dumux/porousmediumflow/3pwateroil/volumevariables.hh
+++ b/dumux/porousmediumflow/3pwateroil/volumevariables.hh
@@ -790,7 +790,7 @@ public:
     }
 
     /*!
-     * \brief Returns the diffusion coeffiecient
+     * \brief Returns the diffusion coefficient
      */
     Scalar diffusionCoefficient(int phaseIdx, int compIdx) const
     {
diff --git a/dumux/porousmediumflow/mpnc/volumevariables.hh b/dumux/porousmediumflow/mpnc/volumevariables.hh
index a67412966aad97c7b2d1ab3425851440632890b9..7a69f44b09f1aa2b3bfdc9a9a268aa84b186f990 100644
--- a/dumux/porousmediumflow/mpnc/volumevariables.hh
+++ b/dumux/porousmediumflow/mpnc/volumevariables.hh
@@ -451,7 +451,7 @@ public:
         else if (compIdx > phaseIdx)
             return diffCoefficient_[phaseIdx][compIdx-1];
         else
-            DUNE_THROW(Dune::InvalidStateException, "Diffusion coeffiecient called for phaseIdx = compIdx");
+            DUNE_THROW(Dune::InvalidStateException, "Diffusion coefficient called for phaseIdx = compIdx");
     }
 
     /*!
@@ -505,7 +505,7 @@ protected:
         else if (compIdx > phaseIdx)
             diffCoefficient_[phaseIdx][compIdx-1] = std::move(d);
         else
-            DUNE_THROW(Dune::InvalidStateException, "Diffusion coeffiecient for phaseIdx = compIdx doesn't exist");
+            DUNE_THROW(Dune::InvalidStateException, "Diffusion coefficient for phaseIdx = compIdx doesn't exist");
     }
 
     std::array<std::array<Scalar, numComponents-1>, numPhases> diffCoefficient_;
diff --git a/dumux/freeflow/navierstokesnc/volumevariables.hh b/dumux/freeflow/navierstokesnc/volumevariables.hh
index de3800a4e698eecab1456896f079af72206f3e17..88a9afd92bf7dea4febec7078d4b2244ead4b8d5 100644
--- a/dumux/freeflow/navierstokesnc/volumevariables.hh
+++ b/dumux/freeflow/navierstokesnc/volumevariables.hh
@@ -192,7 +192,7 @@ public:
     }
 
      /*!
      * \brief Returns the diffusion coeffiecient
      */
     Scalar diffusionCoefficient(int pIdx, int compIdx) const
     {
@@ -202,7 +202,7 @@ public:
         else if (compIdx > pIdx)
             return diffCoefficient_[pIdx][compIdx-1];
         else
-            DUNE_THROW(Dune::InvalidStateException, "Diffusion coeffiecient called for phaseIdx = compIdx");
+            DUNE_THROW(Dune::InvalidStateException, "Diffusion coefficient called for phaseIdx = compIdx");
     }
 
 protected:
@@ -221,7 +221,7 @@ protected:
         else if (compIdx > pIdx)
             diffCoefficient_[pIdx][compIdx-1] = std::move(d);
         else
-            DUNE_THROW(Dune::InvalidStateException, "Diffusion coeffiecient for phaseIdx = compIdx doesn't exist");
+            DUNE_THROW(Dune::InvalidStateException, "Diffusion coefficient for phaseIdx = compIdx doesn't exist");
     }
 
     std::array<std::array<Scalar, numComponents-1>, numPhases> diffCoefficient_;
@@ -192,7 +192,7 @@ public:
 
      /*!
-     * \brief Returns the diffusion coeffiecient
+     * \brief Returns the diffusion coefficient
      */
     Scalar diffusionCoefficient(int pIdx, int compIdx) const
diff --git a/dumux/porousmediumflow/3p3c/volumevariables.hh b/dumux/porousmediumflow/3p3c/volumevariables.hh
index 977ef7ed5803da15b5dc078aeaf1cd5cb2720ed7..7dbbfab8e179bb26503f10a621f793a2448b2fcf 100644
--- a/dumux/porousmediumflow/3p3c/volumevariables.hh
+++ b/dumux/porousmediumflow/3p3c/volumevariables.hh
@@ -666,7 +666,7 @@ public:
     { return permeability_; }
 
     /*!
      * \brief Returns the diffusion coeffiecient
      */
     Scalar diffusionCoefficient(int phaseIdx, int compIdx) const
     {
@@ -675,7 +675,7 @@ public:
         else if (compIdx > phaseIdx)
             return diffCoefficient_[phaseIdx][compIdx-1];
         else
-            DUNE_THROW(Dune::InvalidStateException, "Diffusion coeffiecient called for phaseIdx = compIdx");
+            DUNE_THROW(Dune::InvalidStateException, "Diffusion coefficient called for phaseIdx = compIdx");
     }
 
 protected:
@@ -701,7 +701,7 @@ private:
         else if (phaseIdx == nPhaseIdx)
             diffCoefficient_[phaseIdx][compIdx-1] = 0;
         else
-            DUNE_THROW(Dune::InvalidStateException, "Diffusion coeffiecient for phaseIdx = compIdx doesn't exist");
+            DUNE_THROW(Dune::InvalidStateException, "Diffusion coefficient for phaseIdx = compIdx doesn't exist");
     }
 
     std::array<std::array<Scalar, numComponents-1>, numPhases> diffCoefficient_;
@@ -666,7 +666,7 @@ public:
 
     /*!
-     * \brief Returns the diffusion coeffiecient
+     * \brief Returns the diffusion coefficient
      */
     Scalar diffusionCoefficient(int phaseIdx, int compIdx) const